<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2026-06-29 15:48:56+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Better Search Replace - Stable (latest release)','language'=>'es','messages'=>['Download System Info'=>'Descargar información del sistema','Feedback'=>'Comentarios','Support'=>'Soporte','Documentation'=>'Documentación','%1$s is developed and maintained by %2$s.'=>'%2$s desarrolla y mantiene %1$s.','WP Engine'=>'WP Engine','Upgrade Now'=>'Actualizar ahora','Get up to <span>50% off</span> your first year!'=>'¡Consigue hasta un <span>50% de descuento</span> en tu primer año!','Email support'=>'Soporte por correo electrónico','Export and import WordPress databases'=>'Exporta e importa bases de datos de WordPress','Migrate full sites including themes, plugins, media, and database'=>'Migración de sitios completos, incluyendo temas, plugins, medios y base de datos','Use regular expressions for complex string replacements'=>'Usa expresiones regulares para reemplazar cadenas complejas','Preview database changes before they are saved'=>'Previsualiza los cambios en la base de datos antes de guardarlos','Gain access to more database and migration features'=>'Consigue acceso a más funciones de base de datos y de migración','Upgrade'=>'Actualizar','If you notice timeouts or are unable to backup/import the database, try decreasing this value.'=>'Si recibes avisos de tiempo de espera o no puedes hacer una copia de seguridad/importación de la base de datos, intenta reducir este valor.','Replace GUIDs'=>'Reemplaza los GUID','Additional Settings'=>'Ajustes adicionales','Search and replace text in the database, including serialized arrays and objects. Be sure to back up your database before running this process.'=>'Busca y reemplaza texto en la base de datos, incluyendo matrices y objetos serializados. Asegúrate de hacer una copia de seguridad de la base de datos antes de ejecutar este proceso.','System Info'=>'Información del sistema','Upgrade now and get 50% off'=>'Actualiza ahora y obtén un 50% de descuento','<a href="%s" target="_blank">UPGRADE</a> to view details on the exact changes that will be made.'=>'<a href="%s" target="_blank">ACTUALIZA</a> para ver los detalles de los cambios exactos que se harán.','https://bettersearchreplace.com'=>'https://bettersearchreplace.com',' seconds'=>'segundos','Processing...'=>'Procesando…','A small plugin for running a search/replace on your WordPress database.'=>'Un pequeño plugin para ejecutar una búsqueda/sustitución en tu base de datos de WordPress.','Max Page Size'=>'Tamaño máximo de página','Run Search/Replace'=>'Ejecutar búsqueda/sustitución','If checked, no changes will be made to the database, allowing you to check the results beforehand.'=>'Si activas esta opción, no se realizará ningún cambio en la base de datos, lo cual te permite verificar los resultados de antemano.','Run as dry run'=>'Ejecutar como un simulacro','If left unchecked, all database columns titled \'guid\' will be skipped.'=>'Si no activas esta opción, se omitirán todas las columnas de las bases de datos tituladas «guid».','Searches are case-sensitive by default.'=>'Las búsquedas distinguen entre mayúsculas y minúsculas por defecto.','Case-Insensitive'=>'Sin tener en cuenta mayúsculas/minúsculas','Select multiple tables with Ctrl-Click for Windows or Cmd-Click for Mac.'=>'Elige varias tablas con Ctrl+Clic en Windows o Cmd+Clic en Mac.','Select tables'=>'Seleccionar tablas','Replace with'=>'Sustituir con','Search for'=>'Buscar','Found a bug or have a feature request? Please submit an issue on <a href="%s">GitHub</a>!'=>'¿Has encontrado un fallo o quieres hacer una petición de funcionalidades? Por favor, ¡envía un informe a <a href="%s">GitHub</a>!','Help & Troubleshooting'=>'Ayuda y solución de problemas','Help'=>'Ayuda','Settings'=>'Ajustes','Search/Replace'=>'Búsqueda/sustitución','Error updating row: %d.'=>'Error al actualizar la fila: %d.','(%s MB)'=>'(%s MB)','Upgrade to Pro'=>'Actualiza a Pro','Time'=>'Hora','Rows Updated'=>'Filas actualizadas','Changes Found'=>'Cambios encontrados','Table'=>'Tabla','Better Search Replace'=>'Better Search Replace','An error occurred processing your request. Try decreasing the "Max Page Size", or contact support.'=>'Ocurrió un error al procesar tu petición. Trata de disminuir el parámetro "Max Page Size" o contacta con el equipo de soporte.','Please select the tables that you want to update.'=>'Por favor, selecciona las tablas que quieres actualizar.','No search string was defined, please enter a URL or string to search for.'=>'No se ha definido ninguna cadena de búsqueda, por favor, escribe una URL o cadena que buscar.']];